import { defineStore } from "pinia";
import { http } from "@/serverCom";
import type { AxiosResponse } from "axios";

export const useDatabaseStore = defineStore("database", {
  state: () => {
    return {
      data: {} as any,
      status: "idle" as "idle" | "working" | "success" | "failed",
      failureReason: '' as string,
      ex: {} as Error,
    };
  },
  actions: {
    async import() {
      this.status = "working";
      http
        .post("/admin/database")
        .then((result) => {
          this.data = result.data;
          this.status = "success";
        })
        .catch(() => {
          this.status = "failed";
        });
    },
    async export(secret: string) {
      try {
        this.status = "working";
        const postData = {secret: secret};
        const response: AxiosResponse = await http.post("/admin/database", postData);
        this.data = response.data.data;
        this.status = "success";
      } catch (ex) {
        this.status = "failed";
        this.failureReason = (ex as Error).message;
        this.ex = (ex as Error);
        throw ex;
      }
    },
  },
});
